Release History
===============

dev
---

**Bugfixes**

-   \[Short description of non-trivial change.\]

0.0.1 (2019-11-20)
------------------
Good start definition from requests project [https://requests.readthedocs.io] HISTORY.md :)

-   Frustration
-   Conception